==> guix-binary-0.10.0.i686-linux.tar.xz: lib/guile/2.0/ccache/language/assembly/compile-bytecode.go <==
GOOF----LE-8-2.0T&      ] V 4        h      ] g  guile	 	g  define-module*	 	 	g  language	g  assembly	g  compile-bytecode		 	
g  filenameS	f  &language/assembly/compile-bytecode.scm	g  importsS	
g  system	g  base	g  pmatch	
 	 	g  target	
 	 	 	 	g  vm	g  instruction	
 	 	g  rnrs	g  bytevectors	 	 	g  srfi	 g  srfi-1	!  	"g  selectS	#g  fold	$# 	%!"$ 	&% 	'g  exportsS	( 	)g  set-current-module	*) 	+) 	,g  assq-ref	-g  error	.f  jump too far forward	/f  jump too far backwards	0g  big	1g  instruction->opcode	2g  instruction-length	3f  $unhanded variable-length instruction	4g  length	5g  for-each	6f  !bad number of args to instruction	7g  prompt	8g  mv-call	9g  bind-optionals/shuffle-or-br	:g  br-if-nargs-gt	;g  br-if-nargs-lt	<g  br-if-nargs-ne	=g  br-if-not-null	>g  
br-if-null	?g  br-if-not-eq	@g  br-if-eq	Ag  	br-if-not	Bg  br-if	Cg  br	Dg  
load-array	Eg  bytevector-length	Fg  bytevector-copy!	Gg  load-symbol	Hg  
string-length	Ig  
char->integer	Jg  
string-ref	Kg  load-wide-string	Lg  
string->utf32	Mg  load-string	Ng  load-number	Og  make-char32	Pg  load-program	Qg  byte-length	Rg  make-bytevector	Sf  failed to fill bytevector	Tg  target-endianness	Uf  bad assemblyC 5  hp  r   ]4	
&'(5 4+ >  "  G   ,-./0      h   i   ] LM LC     a       g  filenamef  &language/assembly/compile-bytecode.scm
	\				]		
	]	 		
   C12345   h   s   ]LM  M N Ck       g  x
		  g  filenamef  &language/assembly/compile-bytecode.scm
 			 	' 		   C6789:;<=>?@ABCDEFGHIJKLMNOPQ# h(      ]
M 4L L>  "  G  M C         g  asm
		& g  address		& g  start			&  g  filenamef  &language/assembly/compile-bytecode.scm
	n			o			p		$	q	$	%	q	 		&	   C + hH  
  ]H"  v454J5 	       $  6
  $  6M 
LMM LMM 	LM	M 	M	NCMLO K  4545$  LMMN"   " 	" 	W" " " 9" ~" " " I" " " e" " " ?" " #" "  "  7
$  	 64
5$  LLO 6
 6 $  ^  
		&  H
$  =

$  (
(  LMMN
"h"p"l"h"d"` $  ^  
		&  H
$  =

$  (
(  LMMN
"""""" $   
		&  
$  

$  
$  $  $  $  y$  d(  PLMMNLM
MNLMMNLMMNLMMNLMMN""""""""""" $    
		&  i
$  ^

$  I
$  4(   LMMNLM
MN"k"g"c"_"["W"S $    
		&  i
$  ^

$  I
$  4(   LMMNLM
MN""""""" $    
		&  i
$  ^

$  I
$  4(   LMMNLM
MN"W"K"G"C"?";"7 $  =  
		&  '
$  

(  """"" $  =  
		&  '
$  

(  """"" $  =  
		&  '
$  

(  "w"_"["W"S $  =  
		&  '
$  

(  "/"""" $  =  
		&  '
$  

(  """"" $  =  
		&  '
$  

(  ""{"w"s"o $  =  
		&  '
$  

(  "W"/"+"'"# $    
		&  x
$  m

(  Y45
LM
	LM
	 LM	
 M	N4
LM
>  "  G  M
NC"""" $    
		&  
$  

(  w45
LM
	LM
	 LM	
 M	N"  ,
$  LM4 4!55""  
"M
NC"""" $    
		"&  
$  x

(  d4#L5
4
5LM	LM	 LM	 M	N4
LM>  "  G  MNC"/"+"'"# $    
		$&  
$  

(  w45
LM
	LM
	 LM	
 M	N"  ,
$  LM4 4!55""  
"M
NC"t"p"l"h $    
		%&  
$  

(  w45
LM
	LM
	 LM	
 M	N"  ,
$  LM4 4!55""  
"M
NC"""" $  G  
		&&  1
$  &

(  LMM	NC"c"_"["W $    
		'&  
$  

$  
$  yLM
LM	N$  4(5"  
LMLM	N4)*LLO 
>  "  G  $  
 "C"""""   
      g  asm
	E g  labels	E g  address		E g  emit-opcode?		E g  get-addr		E g  label				 g  offset			 g  start	   g  inst	 E g  args	 E g  opcode	 E g  len	 E g  vx		Y g  vy	
Y g  vx	r g  vy	r g  vx	
 g  vy	 g  vx		 g  vy	
 g  vx	 g  vy	 g  vx	
 g  vy	 g  vx		+( g  vy	
+( g  vx	D  g  vy	D  g  vx	
U g  vy	U g  vx	f g  vy	f g  vx	w g  vy	w g  vx	 g  vy	 g  vx	 g  vy	 g  vx	 g  vy	 g  vx		9 g  vy	
9 g  vx	R g  vy	R g  vx	
c g  vy	c g  vx	t g  vy	t g  vx		< g  vy	
< g  vx	4 g  vy	4 g  vx	
0 g  vy	0 g  vx	, g  vy	, g  vx		M g  vy	
M g  vx	f g  vy	f g  vx	
w g  vy	w g  vx	 g  vy	 g  vx		 g  vy	
 g  vx	 g  vy	 g  vx		V g  vy	
V g  vx	8N g  vy	8N g  vx		g g  vy	
g g  vx	 g  vy	 g  vx		 g  vy	
 g  vx	 g  vy	 g  vx		. g  vy	
. g  vx	& g  vy	& g  vx		?v g  vy	
?v g  vx	Xn g  vy	Xn g  vx		 g  vy	
 g  vx	 g  vy	 g  vx		W g  vy	
W g  vx	O g  vy	O g  len	
K g  vx		h g  vy	
h g  vx	 g  vy	 g  len	
 g  i	 g  vx		 g  vy	
 g  vx	8 g  vy	8 g  x	
K g  len	T g  vx			i g  vy	
	i g  vx		a g  vy		a g  len	
	] g  i		!	M g  vx			z
  g  vy	
	z
  g  vx		
 g  vy		
 g  len	
	
 g  i		
 g  vx		
1
r g  vy	

1
r g  vx	
J
j g  vy	
J
j g  vx		
A g  vy	

A g  vx	
9 g  vy	
9 g  vx	

5 g  vy	
5 g  vx	
1 g  vy	
1 g  x	

  g  filenamef  &language/assembly/compile-bytecode.scm
	U				^		
	_			_	6		_	3		_			_	
	(	`		)	`		-	`		1	`	1	5	`	*	@	a		A	a		E	`		I	a	4	M	a	-	T	b	 	[	
 	d	 	e	 	d	 	f	 	g	 	f	
 	h	 	i	 	j	 	 	! 	% 	& 	/ 	3 	B 	F 	L 	L	j	 	) 	C	j	 	
 	.	j	 	 	 	 	 	 	 		j	 	+ 	; 	K	j	 	+ 	;( 	K,	j	 	+ 	; 	K	j	 	#	j	J 	N	j	 	!	j	 		j	" 	&	j	j 	n	j	 		j			 O	j		~	"	j	C	}	'	j		|	"	a	j			{	"
	j	
\	z	 
j	j	
	l	
	m	
	m	*
	m	&
	m	
	n		t	!	y	(/	y	5	j	 f	E	  g  nameg  write-bytecode CRE-SPQTU 
      h    - 1 3 	"  d
HHO Q 4	5K4 
>  "  G  J45$  DJ456 $    &  w$  h$  P$  74		$  45"  
545 "$	 6	 6	 6	 6	 6             g  assembly
		 g  env		 g  opts			 g  bv		
	q g  target-endianness		
	q g  pos			q g  u32-bv			q g  write-bytecode			q g  vx		~	 g  vy		~	 g  vy	   g  vx	   g  vy	   g  vx	    g  filenamef  &language/assembly/compile-bytecode.scm
	
	
	'			(		-	,		6 		; 		B 		M 		T 	
	X 		` 	
	d 		i 		q 	
	t 	  	  	(  	0  	,  	%  	  	  	  	  	
  	  	
  	 	
 		 	

 	 	
 "			
	  g  nameg  compile-bytecode CRC    j       g  m
		,  g  filenamef  &language/assembly/compile-bytecode.scm		
j	
 	l
   C6 

==> guix-binary-0.13.0.i686-linux.tar.xz: lib/guile/2.0/ccache/language/assembly/compile-bytecode.go <==
GOOF----LE-8-2.0T&      ] V 4        h      ] g  guile	 	g  define-module*	 	 	g  language	g  assembly	g  compile-bytecode		 	
g  filenameS	f  &language/assembly/compile-bytecode.scm	g  importsS	
g  system	g  base	g  pmatch	
 	 	g  target	
 	 	 	 	g  vm	g  instruction	
 	 	g  rnrs	g  bytevectors	 	 	g  srfi	 g  srfi-1	!  	"g  selectS	#g  fold	$# 	%!"$ 	&% 	'g  exportsS	( 	)g  set-current-module	*) 	+) 	,g  assq-ref	-g  error	.f  jump too far forward	/f  jump too far backwards	0g  big	1g  instruction->opcode	2g  instruction-length	3f  $unhanded variable-length instruction	4g  length	5g  for-each	6f  !bad number of args to instruction	7g  prompt	8g  mv-call	9g  bind-optionals/shuffle-or-br	:g  br-if-nargs-gt	;g  br-if-nargs-lt	<g  br-if-nargs-ne	=g  br-if-not-null	>g  
br-if-null	?g  br-if-not-eq	@g  br-if-eq	Ag  	br-if-not	Bg  br-if	Cg  br	Dg  
load-array	Eg  bytevector-length	Fg  bytevector-copy!	Gg  load-symbol	Hg  
string-length	Ig  
char->integer	Jg  
string-ref	Kg  load-wide-string	Lg  
string->utf32	Mg  load-string	Ng  load-number	Og  make-char32	Pg  load-program	Qg  byte-length	Rg  make-bytevector	Sf  failed to fill bytevector	Tg  target-endianness	Uf  bad assemblyC 5  hp  r   ]4	
&'(5 4+ >  "  G   ,-./0      h   i   ] LM LC     a       g  filenamef  &language/assembly/compile-bytecode.scm
	\				]		
	]	 		
   C12345   h   s   ]LM  M N Ck       g  x
		  g  filenamef  &language/assembly/compile-bytecode.scm
 			 	' 		   C6789:;<=>?@ABCDEFGHIJKLMNOPQ# h(      ]
M 4L L>  "  G  M C         g  asm
		& g  address		& g  start			&  g  filenamef  &language/assembly/compile-bytecode.scm
	n			o			p		$	q	$	%	q	 		&	   C + hH  
  ]H"  v454J5 	       $  6
  $  6M 
LMM LMM 	LM	M 	M	NCMLO K  4545$  LMMN"   " 	" 	W" " " 9" ~" " " I" " " e" " " ?" " #" "  "  7
$  	 64
5$  LLO 6
 6 $  ^  
		&  H
$  =

$  (
(  LMMN
"h"p"l"h"d"` $  ^  
		&  H
$  =

$  (
(  LMMN
"""""" $   
		&  
$  

$  
$  $  $  $  y$  d(  PLMMNLM
MNLMMNLMMNLMMNLMMN""""""""""" $    
		&  i
$  ^

$  I
$  4(   LMMNLM
MN"k"g"c"_"["W"S $    
		&  i
$  ^

$  I
$  4(   LMMNLM
MN""""""" $    
		&  i
$  ^

$  I
$  4(   LMMNLM
MN"W"K"G"C"?";"7 $  =  
		&  '
$  

(  """"" $  =  
		&  '
$  

(  """"" $  =  
		&  '
$  

(  "w"_"["W"S $  =  
		&  '
$  

(  "/"""" $  =  
		&  '
$  

(  """"" $  =  
		&  '
$  

(  ""{"w"s"o $  =  
		&  '
$  

(  "W"/"+"'"# $    
		&  x
$  m

(  Y45
LM
	LM
	 LM	
 M	N4
LM
>  "  G  M
NC"""" $    
		&  
$  

(  w45
LM
	LM
	 LM	
 M	N"  ,
$  LM4 4!55""  
"M
NC"""" $    
		"&  
$  x

(  d4#L5
4
5LM	LM	 LM	 M	N4
LM>  "  G  MNC"/"+"'"# $    
		$&  
$  

(  w45
LM
	LM
	 LM	
 M	N"  ,
$  LM4 4!55""  
"M
NC"t"p"l"h $    
		%&  
$  

(  w45
LM
	LM
	 LM	
 M	N"  ,
$  LM4 4!55""  
"M
NC"""" $  G  
		&&  1
$  &

(  LMM	NC"c"_"["W $    
		'&  
$  

$  
$  yLM
LM	N$  4(5"  
LMLM	N4)*LLO 
>  "  G  $  
 "C"""""   
      g  asm
	E g  labels	E g  address		E g  emit-opcode?		E g  get-addr		E g  label				 g  offset			 g  start	   g  inst	 E g  args	 E g  opcode	 E g  len	 E g  vx		Y g  vy	
Y g  vx	r g  vy	r g  vx	
 g  vy	 g  vx		 g  vy	
 g  vx	 g  vy	 g  vx	
 g  vy	 g  vx		+( g  vy	
+( g  vx	D  g  vy	D  g  vx	
U g  vy	U g  vx	f g  vy	f g  vx	w g  vy	w g  vx	 g  vy	 g  vx	 g  vy	 g  vx	 g  vy	 g  vx		9 g  vy	
9 g  vx	R g  vy	R g  vx	
c g  vy	c g  vx	t g  vy	t g  vx		< g  vy	
< g  vx	4 g  vy	4 g  vx	
0 g  vy	0 g  vx	, g  vy	, g  vx		M g  vy	
M g  vx	f g  vy	f g  vx	
w g  vy	w g  vx	 g  vy	 g  vx		 g  vy	
 g  vx	 g  vy	 g  vx		V g  vy	
V g  vx	8N g  vy	8N g  vx		g g  vy	
g g  vx	 g  vy	 g  vx		 g  vy	
 g  vx	 g  vy	 g  vx		. g  vy	
. g  vx	& g  vy	& g  vx		?v g  vy	
?v g  vx	Xn g  vy	Xn g  vx		 g  vy	
 g  vx	 g  vy	 g  vx		W g  vy	
W g  vx	O g  vy	O g  len	
K g  vx		h g  vy	
h g  vx	 g  vy	 g  len	
 g  i	 g  vx		 g  vy	
 g  vx	8 g  vy	8 g  x	
K g  len	T g  vx			i g  vy	
	i g  vx		a g  vy		a g  len	
	] g  i		!	M g  vx			z
  g  vy	
	z
  g  vx		
 g  vy		
 g  len	
	
 g  i		
 g  vx		
1
r g  vy	

1
r g  vx	
J
j g  vy	
J
j g  vx		
A g  vy	

A g  vx	
9 g  vy	
9 g  vx	

5 g  vy	
5 g  vx	
1 g  vy	
1 g  x	

  g  filenamef  &language/assembly/compile-bytecode.scm
	U				^		
	_			_	6		_	3		_			_	
	(	`		)	`		-	`		1	`	1	5	`	*	@	a		A	a		E	`		I	a	4	M	a	-	T	b	 	[	
 	d	 	e	 	d	 	f	 	g	 	f	
 	h	 	i	 	j	 	 	! 	% 	& 	/ 	3 	B 	F 	L 	L	j	 	) 	C	j	 	
 	.	j	 	 	 	 	 	 	 		j	 	+ 	; 	K	j	 	+ 	;( 	K,	j	 	+ 	; 	K	j	 	#	j	J 	N	j	 	!	j	 		j	" 	&	j	j 	n	j	 		j			 O	j		~	"	j	C	}	'	j		|	"	a	j			{	"
	j	
\	z	 
j	j	
	l	
	m	
	m	*
	m	&
	m	
	n		t	!	y	(/	y	5	j	 f	E	  g  nameg  write-bytecode CRE-SPQTU 
      h    - 1 3 	"  d
HHO Q 4	5K4 
>  "  G  J45$  DJ456 $    &  t$  e$  M$  44	$  45"  
545 "'	 6	 6	 6	 6	 6        g  assembly
		 g  env		 g  opts			 g  bv		
	q g  target-endianness		
	q g  pos			q g  u32-bv			q g  write-bytecode			q g  vx		~ g  vy		~ g  vy	   g  vx	   g  vy	   g  vx	    g  filenamef  &language/assembly/compile-bytecode.scm
	
	
	'			(		-	,		6 		; 		B 		M 		T 	
	X 		` 	
	d 		i 		q 	
	t 	  	  	%  	(  	0  	,  	%  	  	  	  	  	
  	  	
  	  	
 	 	

 	 	
 #			
	  g  nameg  compile-bytecode CRC  j       g  m
		,  g  filenamef  &language/assembly/compile-bytecode.scm		
l	
 	n
   C6 
